const express = require('express')
const cookieParser = require('cookie-parser')

// Create Express Server that is started by nuxt to process authenticated
// requests on the serverside as a serverMiddleware. Can function as a proxy
// that authenticates requests.
const app = express()

// Include authentication middleware
const auth = require('./middleware/auth')
const isAdmin = require('./middleware/admin')

// Include routes that creare response transmitted to client
const graphql = require('./routes/graphql')

// Register authentication middleware
app.use(cookieParser())
app.use(auth)
app.use('/admin/', isAdmin)

// Register routes
app.use('/admin/graphql', graphql)

// Export the server middleware
module.exports = {
  path: '/api',
  handler: app
}
